@@ -344,9 +344,9 @@ class RestAPI(object):
 
 		# check-remove double subscriptions.
 		if self.remove_double_subscriptions:
-			rank, plan, cancel_subs = 0, None, {}
+			rank, plan, cancel_subs = None, None, {}
 			for uid, sub_info in subscriptions.items():
-				for plan, plan_info in sub_info["plans"].items():
+				for _plan_, plan_info in sub_info["plans"].items():
 					if plan_info["plan_active_status"]:
 						response = self.__get_plan_by_plan_id__(plan_info["plan_id"])
 						if response["error"] != None: 
@@ -356,13 +356,12 @@ class RestAPI(object):
 						l_rank = self.__plans__[l_plan]["rank"]
 						if plan == None:
 							rank, plan = int(l_rank), str(l_plan)
-						else:
-							if int(l_rank) > int(rank):
-								try:cancel_subs[uid]
-								except KeyError: cancel_subs[uid] = []
-								if plan not in ["free"]:
-									cancel_subs[uid].append(plan)
-								rank, plan = int(l_rank), str(l_plan)
+						elif int(l_rank) > int(rank):
+							rank, plan = int(l_rank), str(l_plan)
+							try:cancel_subs[uid]
+							except KeyError: cancel_subs[uid] = []
+							if plan not in ["free"]:
+								cancel_subs[uid].append(plan)
 					if silent == False: print(f"Found subscription {uid}:{l_plan}, active: {plan_info['plan_active_status']}.")	
 			for uid, plans in cancel_subs.items():
 				for plan in plans:
